@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
-import re
+
+
 import requests
 
 from jsonschema import validate, SchemaError, ValidationError
 
+from pluct import schema
 from pluct.request import Request
 from pluct.schema import Schema
-from pluct import schema
 
 
 def add_methods(resource, s, auth=None):
@@ -14,19 +15,10 @@ def add_methods(resource, s, auth=None):
         method = link.get("method", "GET")
         href = link.get("href")
         rel = link.get("rel")
-        # href = expand(href, resource.data)
         method_class = Request(method, href, auth, resource)
         setattr(resource, rel, method_class.process)
 
 
-def schema_from_header(headers, auth=None):
-    p = re.compile(".*profile=([^;]+);?")
-    schema_url = p.findall(headers.get('content-type', ''))
-    if schema_url:
-        return schema.get(schema_url[0], auth)
-    return None
-
-
 class Resource(object):
 
     def __init__(self, url, data=None, schema=None, auth=None):
@@ -34,10 +26,10 @@ class Resource(object):
         self.url = url
         self.data = data
         self.schema = schema
-        if self.is_valid():
-            if self.schema:
+        if self.schema:
+            if self.is_valid():
                 add_methods(self, self.schema, self.auth)
-            self.parse_data()
+                self.parse_data()
 
     def __repr__(self):
         return str(self.data)
@@ -87,10 +79,17 @@ def get(url, auth=None):
             auth['type'], auth['credentials']
         )
     response = requests.get(url, headers=headers)
-    s = schema_from_header(response.headers, auth)
+    return from_response(response, auth)
+
+
+def from_response(response, auth=None):
+    try:
+        data = response.json()
+    except ValueError:
+        data = {}
     return Resource(
-        url=url,
+        url=response.url,
         auth=auth,
-        data=response.json(),
-        schema=s
+        data=data,
+        schema=schema.from_header(response.headers, auth)
     )
